@@ -16,6 +16,7 @@ CONF_BUTTON = "btn"
 CONF_DEVICENAME = "dn"
 CONF_FRIENDLYNAME = "fn"
 CONF_FULLTOPIC = "ft"
+CONF_IFAN = "if"
 CONF_IP = "ip"
 CONF_HOSTNAME = "hn"
 CONF_MAC = "mac"
@@ -31,6 +32,7 @@ CONF_STATE = "state"
 CONF_RELAY = "rl"
 CONF_SW_VERSION = "sw"
 CONF_SWITCH = "swc"
+CONF_SWITCHNAME = "swn"
 CONF_TOPIC = "t"
 CONF_TUYA = "ty"
 CONF_VERSION = "ver"
@@ -46,6 +48,7 @@ LST_RGBW = 4
 LST_RGBCW = 5
 
 # fmt: off
+OPTION_MQTT_RESPONSE = "4"        # Return MQTT response as RESULT or %COMMAND%
 OPTION_BUTTON_SWAP = "11"         # Swap button single and double press functionality
 OPTION_BUTTON_SINGLE = "13"       # Allow immediate action on single button press
 OPTION_DECIMAL_TEXT = "17"        # Show Color string as hex or comma-separated
@@ -53,8 +56,9 @@ OPTION_NOT_POWER_LINKED = "20"    # Update of Dimmer/Color/CT without turning po
 OPTION_HASS_LIGHT = "30"          # Enforce Home Assistant auto-discovery as light
 OPTION_PWM_MULTI_CHANNELS = "68"  # Multi-channel PWM instead of a single light
 OPTION_MQTT_BUTTONS = "73"        # Enable Buttons decoupling and send multi-press and hold MQTT messages
-OPTION_SHUTTER_MODE = "80"        # Blinds and shutters support
+OPTION_SHUTTER_MODE = "80"        # Blinds and shutters support; removed in Tasmota 9.0.0.4
 OPTION_REDUCED_CT_RANGE = "82"    # Reduce the CT range from 153..500 to 200.380
+OPTION_MQTT_SWITCHES = "114"      # Enable sending switch MQTT messages
 # fmt: on
 
 PREFIX_CMND = 0
@@ -66,7 +70,7 @@ RL_RELAY = 1
 RL_LIGHT = 2
 RL_SHUTTER = 3
 
-RSLT_ACTION = "ACTION"
+RSLT_ACTION = "Action"
 RSLT_POWER = "POWER"
 RSLT_STATE = "STATE"
 RSLT_TRIG = "TRIG"
@@ -119,7 +123,13 @@ SENSOR_CCT = "CCT"
 SENSOR_PROXIMITY = "Proximity"
 SENSOR_AMBIENT = "Ambient"
 SENSOR_SWITCH = "Switch"
+SENSOR_STATUS_MQTT_COUNT = "status_mqtt_count"
+SENSOR_STATUS_LINK_COUNT = "status_link_count"
 SENSOR_STATUS_SIGNAL = "status_signal"
+SENSOR_STATUS_RSSI = "status_rssi"
+SENSOR_STATUS_RESTART = "status_restart_reason"
+SENSOR_STATUS_IP = "status_ip"
+SENSOR_STATUS_UPTIME = "status_Uptime"
 
 SENSOR_UNIT_PRESSURE = "PressureUnit"
 SENSOR_UNIT_SPEED = "SpeedUnit"
